<?php

namespace app\models;

use yii\base\Model;
use yii\data\ActiveDataProvider;
use app\models\Design;

/**
 * DesignSearch represents the model behind the search form of `app\models\Design`.
 */
class DesignSearch extends Design
{
    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['id', 'is_deleted', 'is_printed', 'status', 'created_by', 'updated_by'], 'integer'],
            [['user_id', 'design_name', 'colour_idea', 'design_img', 'design_file', 'design_pdf', 'created_at', 'updated_at'], 'safe'],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function scenarios()
    {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params)
    {
        $query = Design::find();
        $query->joinWith(['user']);
        $query->orderBy([
            'id' => SORT_DESC, //specify sort order ASC for ascending DESC for descending
        ]);

        // add conditions that should always apply here

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
        ]);

        $this->load($params);

        if (!$this->validate()) {
            // uncomment the following line if you do not want to return any records when validation fails
            // $query->where('0=1');
            return $dataProvider;
        }

        // grid filtering conditions
        if(is_numeric($this->user_id)){
            $query->andFilterWhere(['design.user_id' => $this->user_id]);
        } else {
            $query->andFilterWhere(['like', 'user.username', $this->user_id]);
        }
        $query->andFilterWhere([
            'design.id' => $this->id,
            'design.is_deleted' => $this->is_deleted,
            'design.is_printed' => $this->is_printed,
            'design.status' => $this->status,
            'design.created_at' => $this->created_at,
            'design.created_by' => $this->created_by,
            'design.updated_at' => $this->updated_at,
            'design.updated_by' => $this->updated_by,
         ]);

        $query->andFilterWhere(['like', 'design.design_name', $this->design_name]);
        $query->andFilterWhere(['like', 'design.colour_idea', $this->colour_idea]);
        $query->andFilterWhere(['like', 'design.colour_idea', $this->colour_idea]);
        $query->andFilterWhere(['like', 'design.design_img', $this->design_img]);
        $query->andFilterWhere(['like', 'design.design_file', $this->design_file]);
        $query->andFilterWhere(['like', 'design.design_pdf', $this->design_pdf]);


        return $dataProvider;
    }
}
