<?php

namespace app\models;

use Yii;
use yii\base\Model;

/**
 * LoginForm is the model behind the login form.
 *
 * @property User|null $user This property is read-only.
 *
 */
class LoginForm extends Model
{   
    public $username;
    public $email;
    public $password;
    public $rememberMe = true;
    private $_user = false;

    /**
     * @return array the validation rules.
     */
    const SCENARIO_LOGIN = 'login';
    public function rules()
    {
        // return [
        //     // username and password are both required
        //     // [['username', 'password'], 'required'],
        //     [['email', 'password'], 'required'],
        //     [['email'], 'email'],
        //     // rememberMe must be a boolean value
        //     ['rememberMe', 'boolean'],
        //     // password is validated by validatePassword()
        //     ['password', 'validatePassword'],
        // ];
        return [
            // username and password are both required
            [['username', 'password'], 'required'],
            [['email'], 'email'],
            // rememberMe must be a boolean value
            ['rememberMe', 'boolean'],
            // password is validated by validatePassword()
            ['password', 'validatePassword'],
        ];
    }

    /**
     * Validates the password.
     * This method serves as the inline validation for password.
     *
     * @param string $attribute the attribute currently being validated
     * @param array $params the additional name-value pairs given in the rule
     */
    public function validatePassword($attribute, $params)
    {
        if (!$this->hasErrors()) {
            $user = $this->getUser();

            if (!$user || !$user->validatePassword($this->password)) {
                $this->addError($attribute, 'Incorrect username or password.');
            }
        }
    }

    /**
     * Logs in a user using the provided username and password.
     * @return bool whether the user is logged in successfully
     */
    public function login()
    {
        if ($this->validate()) {
            return Yii::$app->user->login($this->getUser(), $this->rememberMe ? 3600*24*30 : 0);
        }
        return false;
    }

    /**
     * Finds user by [[username]]
     *
     * @return User|null
     */
    public function getUser()
    {
        if ($this->_user === false) {
            $this->_user = User::findByUsername($this->username);
            // $this->_user = User::findByEmail($this->email);
        }

        return $this->_user;
    }


    public function scenarios(){
        $scenarios = parent::scenarios();
        $scenarios['login'] = ['username', 'password'];
        return $scenarios;
    }
}
